@@ -9,61 +9,16 @@ import socket
 import threading
 import time
 import ipaddress
-import netifaces
+from typing import Dict, Optional
 import logging
-from typing import Dict, Optional, List, Union, Any
-from dataclasses import dataclass
+
+import netifaces
 from pythonosc.osc_message_builder import OscMessageBuilder
 
 from .fragmented_state_manager import FragmentedStateManager
 from .pixelair_generated import PixelAirDevice as PixelAirDeviceFB
-from .pixelair_device import PixelAirDevice, PixelAirState
-
-
-@dataclass
-class DeviceInfo:
-    """Information about a discovered PixelAir device in the registry."""
-    ip_address: str
-    last_seen: float
-    nickname: Optional[str] = None
-    mac_address: Optional[str] = None
-    device_model: Optional[str] = None
-
-    def __post_init__(self):
-        if self.last_seen is None:
-            self.last_seen = time.time()
-    
-    def update_from_packet(self, device_state: 'PixelAirDeviceFB') -> None:
-        """Update device information from a decoded FlatBuffer packet."""
-        # Update device model
-        if device_state.Model():
-            self.device_model = device_state.Model().decode('utf-8')
-        
-        # Update nickname
-        if device_state.Nickname() and device_state.Nickname().Value():
-            self.nickname = device_state.Nickname().Value().decode('utf-8')
-        
-        # Update MAC address from network info
-        if device_state.Network() and device_state.Network().MacAddress():
-            self.mac_address = device_state.Network().MacAddress().decode('utf-8')
-        
-        # Update last seen timestamp
-        self.last_seen = time.time()
-    
-    def to_dict(self) -> Dict[str, Any]:
-        """Convert to dictionary for easy serialization/display."""
-        return {
-            'ip_address': self.ip_address,
-            'nickname': self.nickname,
-            'mac_address': self.mac_address,
-            'device_model': self.device_model,
-            'last_seen': self.last_seen
-        }
-
-
-# Aliases for consistency
-DiscoveredDeviceInfo = DeviceInfo
-
+from .pixelair_device import PixelAirDevice
+from .device_info import DeviceInfo
 
 class PixelAirClient:
     """
@@ -76,10 +31,7 @@ class PixelAirClient:
     - Packet routing to appropriate devices
     """
     
-    def __init__(self, 
-                 mtu: int = 2048,
-                 bind_address: str = "0.0.0.0",
-                 device_timeout: float = 300.0):
+    def __init__(self):
         """
         Initialize the PixelAir client.
         
@@ -88,10 +40,6 @@ class PixelAirClient:
             bind_address: Address to bind to (default "0.0.0.0" for all interfaces)
             device_timeout: Timeout for considering devices stale (default 5 minutes)
         """
-        self.port = 12345  # Always use port 12345
-        self.mtu = mtu
-        self.bind_address = bind_address
-        self.device_timeout = device_timeout
         
         # Device registry: IP address -> PixelAirDevice (manually registered/configured devices)
         self.devices: Dict[str, PixelAirDevice] = {}
@@ -112,19 +60,9 @@ class PixelAirClient:
         self.listen_thread: Optional[threading.Thread] = None
         self.cleanup_thread: Optional[threading.Thread] = None
         self.discovery_thread: Optional[threading.Thread] = None
-        
-        # Statistics
-        self.stats = {
-            'packets_received': 0,
-            'packets_processed': 0,
-            'fragments_received': 0,
-            'complete_payloads': 0,
-            'errors': 0
-        }
-        self.stats_lock = threading.Lock()
-        
+
         # Logging
-        self.logger = logging.getLogger(f"PixelAirClient:{self.port}")
+        self.logger = logging.getLogger("PixelAirClient")
     
     def start(self) -> bool:
         """
@@ -143,9 +81,9 @@ class PixelAirClient:
             self.socket.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
             
             # Set receive buffer size based on MTU
-            self.socket.setsockopt(socket.SOL_SOCKET, socket.SO_RCVBUF, self.mtu * 16)
+            self.socket.setsockopt(socket.SOL_SOCKET, socket.SO_RCVBUF, 2048 * 16)
             
-            self.socket.bind((self.bind_address, self.port))
+            self.socket.bind(("0.0.0.0", 12345))
             self.socket.settimeout(1.0)  # 1 second timeout for clean shutdown
             
             # Create discovery socket for broadcasting
@@ -169,11 +107,11 @@ class PixelAirClient:
             # Send initial discovery broadcast
             self._send_discovery_broadcast()
             
-            self.logger.info(f"PixelAirClient started on {self.bind_address}:{self.port}")
+            self.logger.info("PixelAirClient started.")
             return True
             
         except Exception as e:
-            self.logger.error(f"Failed to start client: {e}")
+            self.logger.error("Failed to start client (OSError): %s", e)
             self.running = False
             if self.socket:
                 self.socket.close()
@@ -225,13 +163,13 @@ class PixelAirClient:
         """
         with self.devices_lock:
             if ip_address in self.devices:
-                self.logger.warning(f"Device {ip_address} already registered")
+                self.logger.warning("Device %s already registered", ip_address)
                 return False
             
             # Create PixelAirDevice instance directly (no more circular import)
             device = PixelAirDevice(ip_address)
             self.devices[ip_address] = device
-            self.logger.info(f"Registered PixelAir device: {device}")
+            self.logger.info("Registered PixelAir device: %s", ip_address)
             return True
     
     def unregister_device(self, ip_address: str) -> bool:
@@ -249,7 +187,7 @@ class PixelAirClient:
                 return False
             
             device = self.devices.pop(ip_address)
-            self.logger.info(f"Unregistered device: {device}")
+            self.logger.info("Unregistered device: %s", device.ip_address)
             
             # Clean up fragment manager for this device
             with self.fragment_lock:
@@ -300,94 +238,8 @@ class PixelAirClient:
         """
         with self.discovered_lock:
             return self.discovered_devices.copy()
-    
-    def clear_discovered_devices(self):
-        """Clear the discovered devices list."""
-        with self.discovered_lock:
-            count = len(self.discovered_devices)
-            self.discovered_devices.clear()
-            self.logger.info(f"Cleared {count} discovered device(s)")
-    
-    def remove_discovered_device(self, ip_address: str) -> bool:
-        """
-        Remove a specific device from the discovered list.
         
-        Args:
-            ip_address: IP address of the device to remove
-            
-        Returns:
-            True if device was removed, False if not found
-        """
-        with self.discovered_lock:
-            if ip_address in self.discovered_devices:
-                del self.discovered_devices[ip_address]
-                self.logger.info(f"Removed discovered device: {ip_address}")
-                return True
-            return False
-    
-    def get_discovered_device(self, ip_address: str) -> Optional[DeviceInfo]:
-        """
-        Get a specific discovered device by IP address.
-        
-        Args:
-            ip_address: IP address of the device
-            
-        Returns:
-            DeviceInfo instance or None if not found
-        """
-        with self.discovered_lock:
-            return self.discovered_devices.get(ip_address)
-    
-    def get_discovered_devices_by_model(self, model: str) -> List[DeviceInfo]:
-        """
-        Get all discovered devices of a specific model.
-        
-        Args:
-            model: Device model to filter by
-            
-        Returns:
-            List of DeviceInfo instances matching the model
-        """
-        with self.discovered_lock:
-            return [device for device in self.discovered_devices.values() 
-                   if device.device_model == model]
-    
-    def get_discovered_devices_summary(self) -> Dict[str, Any]:
-        """
-        Get a summary of all discovered devices.
-        
-        Returns:
-            Dictionary with summary information about discovered devices
-        """
-        with self.discovered_lock:
-            devices = list(self.discovered_devices.values())
-            
-        total_count = len(devices)
-        models = {}
-        with_nicknames = 0
-        with_mac_addresses = 0
-        
-        for device in devices:
-            # Count by model
-            model = device.device_model or "Unknown"
-            models[model] = models.get(model, 0) + 1
-            
-            # Count devices with additional info
-            if device.nickname:
-                with_nicknames += 1
-            if device.mac_address:
-                with_mac_addresses += 1
-        
-        return {
-            'total_discovered': total_count,
-            'models': models,
-            'devices_with_nicknames': with_nicknames,
-            'devices_with_mac_addresses': with_mac_addresses,
-            'devices': [device.to_dict() for device in devices]
-        }
-    
-    def _track_discovered_device(self, ip_address: str, 
-                                device_state: Optional[PixelAirDeviceFB] = None) -> DeviceInfo:
+    def _handle_discovery(self, ip_address: str, device_state: PixelAirDeviceFB) -> DeviceInfo:
         """
         Track a discovered device (does NOT auto-register it).
         
@@ -419,9 +271,6 @@ class PixelAirClient:
                     device_info.update_from_packet(device_state)
                 
                 self.discovered_devices[ip_address] = device_info
-                self.logger.debug(f"Discovered new device: {ip_address} "
-                                f"(model: {device_info.device_model or 'unknown'}, "
-                                f"nickname: {device_info.nickname or 'none'})")
         
         return device_info
     
@@ -439,31 +288,15 @@ class PixelAirClient:
     
     def _handle_complete_payload(self, ip_address: str, payload: bytes, is_response: bool):
         """Handle a complete defragmented payload from a device."""
-        with self.stats_lock:
-            self.stats['complete_payloads'] += 1
         
         # Check if this is a registered device
         device = self.get_device(ip_address)
         if device is not None:
-            # This is a registered device - handle the packet
-            device.update_last_seen()
-            try:
-                device.handle_packet(payload, is_response)
-            except Exception as e:
-                self.logger.error(f"Error handling packet for device {ip_address}: {e}")
-                with self.stats_lock:
-                    self.stats['errors'] += 1
+            device.handle_packet(payload, is_response)
         else:
-            # This is NOT a registered device - decode and track it as discovered
-            try:
-                # Decode the payload to extract device information
-                device_state = PixelAirDeviceFB.GetRootAs(payload)
-                self._track_discovered_device(ip_address, device_state=device_state)
-                self.logger.debug(f"Received packet from unregistered device {ip_address} - tracked as discovered")
-            except Exception as e:
-                # If decoding fails, still track basic discovery info
-                self._track_discovered_device(ip_address)
-                self.logger.debug(f"Received packet from unregistered device {ip_address} - tracked as discovered (decode failed: {e})")
+            # Decode the payload to extract device information
+            device_state = PixelAirDeviceFB.GetRootAs(payload)
+            self._handle_discovery(ip_address, device_state=device_state)
     
     def _listen_loop(self):
         """Main UDP listening loop."""
@@ -471,39 +304,16 @@ class PixelAirClient:
         
         while self.running and self.socket:
             try:
-                data, address = self.socket.recvfrom(self.mtu)
+                data, address = self.socket.recvfrom(2048)
                 ip_address = address[0]
-                self.logger.debug(f"Received {len(data)} bytes from {ip_address}")
-                
-                with self.stats_lock:
-                    self.stats['packets_received'] += 1
-                    self.stats['fragments_received'] += 1
                 
+                self.logger.info(f"Received {len(data)} bytes from {ip_address}")
+
                 # Get fragment manager for this device
                 fragment_manager = self._get_fragment_manager(ip_address)
-                
-                # Process the fragment
-                try:
-                    fragment_manager.process_buffer(data)
-                    with self.stats_lock:
-                        self.stats['packets_processed'] += 1
-                        
-                except Exception as e:
-                    self.logger.error(f"Error processing fragment from {ip_address}: {e}")
-                    with self.stats_lock:
-                        self.stats['errors'] += 1
-                
-            except socket.timeout:
-                # Normal timeout, continue loop
+                fragment_manager.process_buffer(data)
+            except Exception:
                 continue
-            except OSError as e:
-                if self.running:
-                    self.logger.error(f"Socket error in listen loop: {e}")
-                break
-            except Exception as e:
-                self.logger.error(f"Unexpected error in listen loop: {e}")
-                with self.stats_lock:
-                    self.stats['errors'] += 1
         
         self.logger.info("UDP listener stopped")
     
@@ -523,44 +333,21 @@ class PixelAirClient:
                 # Find stale registered devices
                 with self.devices_lock:
                     for ip_address, device in self.devices.items():
-                        if device.is_stale(self.device_timeout):
+                        if device.is_stale(300):
                             stale_devices.append(ip_address)
                 
                 # Find stale discovered devices
                 with self.discovered_lock:
                     for ip_address, device_info in self.discovered_devices.items():
-                        if current_time - device_info.last_seen > self.device_timeout:
+                        if current_time - device_info.last_seen > 300:
                             stale_discovered.append(ip_address)
                 
                 # Remove stale registered devices
                 for ip_address in stale_devices:
-                    self.logger.info(f"Removing stale registered device: {ip_address}")
                     self.unregister_device(ip_address)
                 
-                # Remove stale discovered devices
-                for ip_address in stale_discovered:
-                    self.logger.info(f"Removing stale discovered device: {ip_address}")
-                    self.remove_discovered_device(ip_address)
-                
-            except Exception as e:
-                self.logger.error(f"Error in cleanup loop: {e}")
-    
-    def get_stats(self) -> Dict:
-        """Get client statistics."""
-        with self.stats_lock:
-            stats = self.stats.copy()
-        
-        stats['devices_registered'] = len(self.devices)
-        stats['devices_discovered'] = len(self.discovered_devices)
-        stats['fragment_managers'] = len(self.fragment_managers)
-        
-        return stats
-    
-    def reset_stats(self):
-        """Reset client statistics."""
-        with self.stats_lock:
-            for key in self.stats:
-                self.stats[key] = 0
+            except Exception:
+                continue
     
     def __enter__(self):
         """Context manager entry."""
@@ -588,22 +375,9 @@ class PixelAirClient:
                             }
         except Exception as e:
             self.logger.error(f"Error getting interface IPs: {e}")
-            # Fallback to basic socket method
-            try:
-                s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-                s.connect(("8.8.8.8", 80))
-                fallback_ip = s.getsockname()[0]
-                interface_data['default'] = {
-                    'ip': fallback_ip,
-                    'netmask': '255.255.255.0'  # Assume common netmask
-                }
-                s.close()
-            except Exception as fallback_e:
-                self.logger.error(f"Fallback IP detection failed: {fallback_e}")
-        
         return interface_data
     
-    def _send_discovery_packet(self, interface_name: str, interface_ip: str, netmask: str):
+    def _send_discovery_packet(self, interface_ip: str, netmask: str):
         """
         Send a discovery packet on a specific interface.
         
@@ -612,46 +386,36 @@ class PixelAirClient:
             interface_ip: IP address of the interface
             netmask: Netmask of the interface
         """
+        
+        builder = OscMessageBuilder("/fluoraDiscovery")
+        
+        # Convert IP address to ASCII integers
+        for char in interface_ip:
+            builder.add_arg(ord(char))
+        
+        # Get the OSC message bytes
+        msg = builder.build()
+        osc_bytes = msg.dgram
+        
+        # Calculate proper broadcast address using ipaddress module
         try:
-            # Build OSC message with IP address as ASCII integers
-            builder = OscMessageBuilder("/fluoraDiscovery")
-            
-            # Convert IP address to ASCII integers
-            for char in interface_ip:
-                builder.add_arg(ord(char))
-            
-            # Get the OSC message bytes
-            msg = builder.build()
-            osc_bytes = msg.dgram
-            
-            # Calculate proper broadcast address using ipaddress module
-            try:
-                host = ipaddress.IPv4Address(interface_ip)
-                network = ipaddress.IPv4Network(f"{interface_ip}/{netmask}", strict=False)
-                broadcast_ip = str(network.broadcast_address)
-                
-                self.logger.debug(f"Interface {interface_name}: IP={interface_ip}, "
-                                f"Mask={netmask}, Network={network}, Broadcast={broadcast_ip}")
-                
-            except (ipaddress.AddressValueError, ipaddress.NetmaskValueError) as e:
-                self.logger.warning(f"Failed to calculate broadcast for {interface_ip}/{netmask}: {e}")
-                # Fallback to simple .255 replacement
-                ip_parts = interface_ip.split('.')
-                if len(ip_parts) == 4:
-                    broadcast_ip = f"{ip_parts[0]}.{ip_parts[1]}.{ip_parts[2]}.255"
-                else:
-                    broadcast_ip = "255.255.255.255"
-            
-            if hasattr(self.discovery_socket, 'sendto') is False:
-                self.logger.info("Discovery socket is not available for sending")
-                return
-            
-            # Send to port 9090
-            self.discovery_socket.sendto(osc_bytes, (broadcast_ip, 9090))
-            self.logger.debug(f"Sent discovery packet from {interface_name} ({interface_ip}) to {broadcast_ip}:9090")
-            
-        except Exception as e:
-            self.logger.error(f"Error sending discovery packet on {interface_name}: {e}")
+            network = ipaddress.IPv4Network(f"{interface_ip}/{netmask}", strict=False)
+            broadcast_ip = str(network.broadcast_address)
+
+        except (ipaddress.AddressValueError, ipaddress.NetmaskValueError):
+            ip_parts = interface_ip.split('.')
+            if len(ip_parts) == 4:
+                broadcast_ip = f"{ip_parts[0]}.{ip_parts[1]}.{ip_parts[2]}.255"
+            else:
+                broadcast_ip = "255.255.255.255"
+        
+        if hasattr(self.discovery_socket, 'sendto') is False:
+            self.logger.info("Discovery socket is not available for sending")
+            return
+        
+        # Send to port 9090
+        self.discovery_socket.sendto(osc_bytes, (broadcast_ip, 9090))
+        self.logger.info(f"Sent discovery packet on {interface_ip} (broadcast {broadcast_ip})")
     
     def _send_discovery_broadcast(self):
         """Send discovery packets on all available interfaces."""
@@ -664,11 +428,9 @@ class PixelAirClient:
             self.logger.warning("No network interfaces found for discovery broadcast")
             return
             
-        for interface_name, data in interface_data.items():
-            self._send_discovery_packet(interface_name, data['ip'], data['netmask'])
-            
-        self.logger.info(f"Sent discovery broadcast on {len(interface_data)} interface(s)")
-    
+        for _, data in interface_data.items():
+            self._send_discovery_packet(data['ip'], data['netmask'])
+
     def _discovery_loop(self):
         """Background loop for sending discovery packets every minute."""
         while self.running:
@@ -680,11 +442,5 @@ class PixelAirClient:
                     
                 self._send_discovery_broadcast()
                 
-            except Exception as e:
-                self.logger.error(f"Error in discovery loop: {e}")
-    
-    def __str__(self) -> str:
-        return f"PixelAirClient(port={self.port}, devices={len(self.devices)})"
-    
-    def __repr__(self) -> str:
-        return self.__str__()
+            except Exception:
+                continue
