@@ -5,6 +5,7 @@ This module provides the PixelAirDevice class that handles individual device sta
 packet decoding, and OSC command sending.
 """
 
+import asyncio
 import socket
 import time
 import logging
@@ -13,17 +14,7 @@ from typing import Dict, Optional, List, Union, Any
 from pythonosc.osc_message_builder import OscMessageBuilder
 
 from .pixelair_generated import PixelAirDevice as PixelAirDeviceFB
-
-
-class PixelAirState:
-    """State information for a PixelAir device."""
-    nickname: Optional[str] = None
-    model: Optional[str] = None
-    serial_number: Optional[str] = None
-    
-    brightness: int = 0  # 0-100
-    is_on: bool = False  # True if the device is on
-
+from .pixelair_state import PixelAirState
 
 class PixelAirDevice:
     """
@@ -47,14 +38,12 @@ class PixelAirDevice:
         
         # Device state tracking
         self.last_decoded_state: Optional[PixelAirDeviceFB] = None
-        self.decode_errors = 0
-        self.successful_decodes = 0
         self.state = PixelAirState()
         
         # Logger for this device
         self.logger = logging.getLogger(f"PixelAirDevice:{self.ip_address}")
     
-    def set_power(self, on: bool) -> bool:
+    async def set_power(self, on: bool) -> bool:
         """
         Set the power state of the device.
         
@@ -66,9 +55,9 @@ class PixelAirDevice:
         """
         route = "/SyYOTiXjQBjW"
         params = [1 if on else 0]
-        return self._send_osc_message(route, params)
+        return await self._send_osc_message(route, params)
     
-    def set_brightness(self, brightness: int) -> bool:
+    async def set_brightness(self, brightness: int) -> bool:
         """
         Set the brightness of the device.
         
@@ -84,9 +73,9 @@ class PixelAirDevice:
         
         route = "/Uv7aMFw5P2lX"
         params = [float(brightness) / 100.0]
-        return self._send_osc_message(route, params)
+        return await self._send_osc_message(route, params)
     
-    def _send_osc_message(self, route: str, params: List[Union[int, float, str, bool]] = None) -> bool:
+    async def _send_osc_message(self, route: str, params: List[Union[int, float, str, bool]] = None) -> bool:
         """
         Send a binary OSC message to the device on port 6767.
         
@@ -123,10 +112,9 @@ class PixelAirDevice:
             # Build the binary message
             osc_message = msg_builder.build()
             
-            # Create UDP socket and send the message
-            with socket.socket(socket.AF_INET, socket.SOCK_DGRAM) as sock:
-                sock.settimeout(5.0)  # 5 second timeout
-                sock.sendto(osc_message.dgram, (self.ip_address, 6767))
+            # Send the message asynchronously
+            loop = asyncio.get_running_loop()
+            await loop.run_in_executor(None, self._send_udp_message, osc_message.dgram)
                 
             self.logger.debug(f"Sent OSC message to {self.ip_address}:6767 - Route: {route}, Params: {params}")
             return True
@@ -135,6 +123,16 @@ class PixelAirDevice:
             self.logger.error(f"Failed to send OSC message to {self.ip_address}:6767 - Route: {route}, Error: {e}")
             return False
     
+    def _send_udp_message(self, dgram: bytes) -> None:
+        """
+        Send a UDP datagram synchronously.
+        
+        This method is called from an executor to avoid blocking the event loop.
+        """
+        with socket.socket(socket.AF_INET, socket.SOCK_DGRAM) as sock:
+            sock.settimeout(5.0)  # 5 second timeout
+            sock.sendto(dgram, (self.ip_address, 6767))
+    
     def handle_packet(self, payload: bytes, is_response: bool):
         """
         Handle a complete defragmented packet from this device.
@@ -147,26 +145,18 @@ class PixelAirDevice:
             is_response: True if this is a response to a request, False if proactive
         """
         self.update_last_seen()
-        
+        self.logger.info(f"Received packet: {len(payload)} bytes, is_response={is_response}")
+
         try:
-            # Decode the payload as a PixelAir FlatBuffer
             device_state = PixelAirDeviceFB.GetRootAs(payload)
             self.last_decoded_state = device_state
-            self.successful_decodes += 1
-            
-            # Log successful decode
-            self.logger.debug(f"Successfully decoded {len(payload)} byte packet "
-                            f"({'response' if is_response else 'proactive'})")
             
             # Call the state packet handler
             self.handle_state_packet(device_state, is_response)
+            self.logger.info(f"Successfully processed packet from {self.ip_address}")
             
         except Exception as e:
-            self.decode_errors += 1
-            self.logger.error(f"Failed to decode packet: {e}")
-            
-            # Call the error handler
-            self.handle_decode_error(payload, is_response, e)
+            self.logger.error(f"Failed to decode packet from {self.ip_address}: {e}")
     
     def handle_state_packet(self, device_state: PixelAirDeviceFB, is_response: bool):
         """
@@ -193,105 +183,32 @@ class PixelAirDevice:
             self.state.is_on = device_state.Engine().IsDisplaying().Value()
             if device_state.Engine().Brightness():
                 self.state.brightness = device_state.Engine().Brightness().Value() * 100.0
-        
-        self.logger.info(f"State: {self.state.model} - Power: {'ON' if self.state.is_on else 'OFF'}, "
-                        f"Brightness: {self.state.brightness:.1f}%")
-    
-    def handle_decode_error(self, payload: bytes, is_response: bool, error: Exception):
+
+        # Log state update with meaningful information
+        power_state = "ON" if self.state.is_on else "OFF"
+        self.logger.info(f"State update - Model: {self.state.model}, Power: {power_state}, Brightness: {self.state.brightness:.1f}%")
+
+    def get_device_info(self) -> Optional[Dict[str, Any]]:
         """
-        Handle a packet decode error.
-        
-        This method is called when packet decoding fails and can be overridden
-        by subclasses to implement custom error handling.
-        
-        Args:
-            payload: Raw payload that failed to decode
-            is_response: True if this is a response to a request, False if proactive
-            error: The exception that occurred during decoding
-        """
-        msg_type = "response" if is_response else "proactive"
-        self.logger.error(f"Decode error for {msg_type} packet from {self.ip_address}: {error}")
-        self.logger.error(f"Payload size: {len(payload)} bytes")
-        
-        # Log first few bytes for debugging
-        preview = payload[:16] if len(payload) >= 16 else payload
-        hex_preview = ' '.join(f'{b:02x}' for b in preview)
-        self.logger.error(f"Payload preview: {hex_preview}")
-    
-    def get_device_info(self) -> Dict[str, Any]:
-        """
-        Get current device information from the last decoded state.
+        Get device information dictionary.
         
         Returns:
-            Dictionary containing device information, or empty dict if no state
+            Dictionary with device information or None if no state available
         """
-        if not self.last_decoded_state:
-            return {}
+        if self.last_decoded_state is None:
+            return None
         
-        state = self.last_decoded_state
-        info = {
-            'ip_address': self.ip_address,
-            'protocol': state.Protocol(),
-            'version': state.Version(),
-            'model': state.Model(),
-            'serial_number': state.SerialNumber(),
-            'rssi': state.Rssi(),
-            'last_seen': self.last_seen,
-            'successful_decodes': self.successful_decodes,
-            'decode_errors': self.decode_errors
-        }
-        
-        # Add optional components
-        if state.Nickname():
-            info['nickname'] = state.Nickname().Label()
-        
-        if state.Network():
-            info['has_network_config'] = True
-        
-        if state.Audio():
-            info['has_audio_config'] = True
-        
-        if state.Engine():
-            info['has_engine_config'] = True
-        
-        if state.Clock():
-            info['has_clock_config'] = True
-        
-        return info
-    
-    def get_protocol_info(self) -> Optional[str]:
-        """Get the protocol from the last decoded state."""
-        return self.last_decoded_state.Protocol() if self.last_decoded_state else None
-    
-    def get_device_version(self) -> Optional[str]:
-        """Get the version from the last decoded state."""
-        return self.last_decoded_state.Version() if self.last_decoded_state else None
-    
-    def get_device_model(self) -> Optional[str]:
-        """Get the model from the last decoded state."""
-        return self.last_decoded_state.Model() if self.last_decoded_state else None
-    
-    def get_serial_number(self) -> Optional[str]:
-        """Get the serial number from the last decoded state."""
-        return self.last_decoded_state.SerialNumber() if self.last_decoded_state else None
-    
-    def get_rssi(self) -> int:
-        """Get the RSSI from the last decoded state."""
-        return self.last_decoded_state.Rssi() if self.last_decoded_state else 0
-    
-    def get_decode_stats(self) -> Dict[str, int]:
-        """
-        Get packet decode statistics.
-        
-        Returns:
-            Dictionary with successful_decodes and decode_errors counts
-        """
         return {
-            'successful_decodes': self.successful_decodes,
-            'decode_errors': self.decode_errors,
-            'total_packets': self.successful_decodes + self.decode_errors
+            "ip_address": self.ip_address,
+            "model": self.state.model,
+            "serial_number": self.state.serial_number,
+            "nickname": self.state.nickname,
+            "is_on": self.state.is_on,
+            "brightness": self.state.brightness,
+            "last_seen": self.last_seen
         }
     
+    
     def update_last_seen(self):
         """Update the last seen timestamp."""
         self.last_seen = time.time()
@@ -309,9 +226,7 @@ class PixelAirDevice:
         return time.time() - self.last_seen > timeout
     
     def __str__(self) -> str:
-        model = self.get_device_model() or "Unknown"
-        serial = self.get_serial_number() or "Unknown"
-        return f"PixelAirDevice({self.ip_address}, model={model}, serial={serial})"
+        return f"PixelAirDevice({self.ip_address})"
     
     def __repr__(self) -> str:
         return self.__str__()
